Hyppää sisältöön

Allas-tallennuspalvelun käyttäminen sensitiivisen tutkimusdatan vastaanottamiseen

Nämä ohjeet antavat esimerkin siitä, miten tutkimusryhmä voi käyttää Allas-palvelua vastaanottaakseen sensitiivistä dataa ulkoiselta datan tarjoajalta, kuten sekvensointikeskukselta. Monissa tapauksissa SD Connect tarjoaa helpomman tavan vastaanottaa sensitiivistä dataa, mutta joissakin tapauksissa SD Connectia ei voida käyttää. Esimerkiksi SD Connect ei pysty tarjoamaan salattua tiedostoa, jonka voisit myöhemmin purkaa ympäristössä, jossa ei ole internetyhteyttä.

Allas

Allas-tallennuspalvelu on CSC:n ylläpitämä yleiskäyttöinen datan tallennuspalvelu.
Se tarjoaa maksutonta tallennustilaa suomalaisten yliopistojen ja tutkimuslaitosten akateemisille tutkimushankkeille.
Allasta voidaan käyttää kaikenlaisen tutkimusdatan tallentamiseen tutkimushankkeen aktiivisen työskentelyvaiheen aikana.
Allasta ei kuitenkaan ole tarkoitettu datan arkistointiin. Sinun on poistettava datasi Altaasta, kun tutkimushanke päättyy.

Altaassa ei ole automaattisia varmuuskopiointiprosesseja. Teknisellä tasolla Allas on erittäin luotettava ja vikasietoinen,
mutta jos sinä tai joku projektisi jäsenistä poistaa tai ylikirjoittaa dataa Altaassa,
se menetetään pysyvästi. Siksi kannattaa harkita datan varmuuskopioimista myös johonkin toiseen sijaintiin.

Vaiheet 1 (Tallennustilan hankkiminen Altaasta) ja 2 (Salausavainten luominen) vaativat jonkin verran työtä,
mutta ne tarvitsee tehdä vain kerran. Kun avaimet ovat valmiina, voit siirtyä suoraan vaiheeseen 3, kun sinun
täytyy valmistella uusi jaettu ämpäri.

1. Tallennustilan hankkiminen Altaasta

Jos käytät jo Allas-palvelua, voit ohittaa tämän luvun ja aloittaa luvusta 2. Muussa tapauksessa tee seuraavat vaiheet saadaksesi käyttöoikeuden Altaaseen.

Vaihe 1.1. Luo käyttäjätili

Jos et ole vielä CSC:n asiakas, rekisteröidy CSC:lle. Voit tehdä nämä vaiheet
CSC:n asiakasportaalissa MyCSC.

Luo CSC-käyttäjätunnus kirjautumalla MyCSC:hen Hakan tai Virtun kautta.

Vaihe 1.2. Luo projekti tai liity projektiin

CSC-käyttäjätilin lisäksi käyttäjien täytyy joko liittyä olemassa olevaan CSC-projektiin
tai perustaa uusi CSC-projekti. Voit käyttää samaa projektia myös muiden
CSC-palveluiden, kuten SD Desktopin, SD Connectin tai Roihun, käyttöön.

Jos sinulla on oikeus toimia projektipäällikkönä, voit luoda uuden CSC-projektin MyCSC:ssä ja hakea käyttöoikeutta Allakseen. Valitse projektityypiksi 'Academic'. Projektipäällikkönä voit kutsua muita käyttäjiä projektisi jäseniksi.

Jos haluat liittyä olemassa olevaan projektiin, pyydä projektipäällikköä lisäämään CSC-käyttäjätilisi
projektin jäsenlistalle.

Vaihe 1.3. Lisää Allas-käyttöoikeus projektiisi

Lisää Allas-palvelu projektiisi MyCSC:ssä. Vain projektipäällikkö voi lisätä palveluita.
Kun olet lisännyt Allaksen projektiin, muiden projektin jäsenten täytyy kirjautua
MyCSC:hen ja hyväksyä palvelun käyttöehdot ennen kuin he saavat käyttöoikeuden Allakseen.

Näiden vaiheiden jälkeen projektillasi on käytettävissä 10 TB tallennustilaa Altaassa.
Ole hyvä ja ota yhteyttä CSC:n Service Deskiin, jos tarvitset lisää tallennustilaa.
Altaassa oleva data voidaan ladata paikalliseen ympäristöösi tai CSC:n tietokoneille.
Lisätietoa eri tavoista käyttää Allaksessa olevaa dataa löytyy Allaksen käyttöoppaasta.

2. Salausavainten luominen sensitiivisen datan salaamiseen

2.1 Mihin salausavaimia tarvitaan?

Sensitiivisen tutkimusdatan, esimerkiksi ihmisen nukleotidisekvenssidatan, tapauksessa
data täytyy salata asianmukaisesti ennen kuin se voidaan ladata Allakseen.
CSC:n sensitiivisen datan palveluita tutkimukselle salaa datan oletusarvoisesti CSC-kohtaisella
avaimella, jota voidaan käyttää vain CSC-ympäristössä. Jos haluat käyttää
sensitiivistä dataasi myös muissa sijainneissa, sinun täytyy luoda omaan käyttöösi Crypt4GH-yhteensopiva avainpari,
joka koostuu salaisesta avaimesta ja julkisesta avaimesta. Voit käyttää samaa avainparia
useita kertoja, ja yleensä on käytännöllistä käyttää samoja avaimia projektin kaikelle datalle, jotta
avainten hallinta ei muutu liian monimutkaiseksi.

Alta löydät vaiheittaiset ohjeet salausavainten luomiseen Cryp4GH:n graafisella käyttöliittymällä tai komentorivin kautta.

Kun avaimet on luotu, voit lähettää julkisen avaimen kaikille datan tuottajille,
jotta he voivat salata datan, jonka he lähettävät sinulle. Tämän jälkeen vain
yksityisen avaimen omistajat eli projektin jäsenet voivat purkaa datan salauksen.

Datan salaukseen liittyvä mahdollinen vaara on se, että jos salainen avain tai
sen salasana katoaa, dataa ei voida enää millään keinolla purkaa.
Siksi avaimet ja salasana kannattaa tallentaa niin, että tiedot säilyvät myös silloin, kun
palvelimet ja projektin jäsenet vaihtuvat. Toisaalta
salainen avain tulisi siirtää vain niihin paikkoihin, joissa salausta puretaan, ja salasanan tulisi pysyä projektin ulkopuolisten saavuttamattomissa.

CSC ei tällä hetkellä tarjoa salausavainten hallintajärjestelmää. Jos sinulla ei ole käytössäsi asianmukaista avaintenhallintajärjestelmää, yksi ratkaisu on
tallentaa salainen avain ja salasanan sisältävä tekstitiedosto CSC:n sensitiivisen
datan palveluihin
käyttäen SD Connect -palvelua.
SD Connect salaa tämän datan CSC:n julkisella avaimella, minkä jälkeen projektin jäsenet,
ja vain he, voivat käyttää SD Desktop -palvelua tarkistaakseen, mitä avaimia ja
salasanoja projekti käyttää.

CSC:n sensitiivisen datan ympäristö käyttää Crypt4GH-salaustyökalua, joka mahdollistaa
salauksen useilla julkisilla avaimilla. Tällä tavalla salattu data voidaan
avata useilla salaisilla avaimilla. Jos hyödynnät CSC:n sensitiivisen datan palveluita,
on kätevää käyttää salauksessa sekä projektin julkista avainta että CSC:n julkista avainta.
Näin dataa voidaan käyttää sekä käyttäjien paikallisessa ympäristössä että
CSC:n sensitiivisen datan palveluissa.

crypt4gh-yhteensopivien avainten luominen graafisen käyttöliittymän kautta

  1. Luo salausavainparisi (salainen avain ja julkinen avain) Crypt4GH-sovelluksella (voit ohittaa tämän kappaleen, jos sinulla on jo avainpari).

    • Asenna Crypt4GH-sovellus:

    CSC on kehittänyt yksinkertaisen sovelluksen, jonka avulla voit luoda salausavaimesi ja purkaa datan salauksen tarvittaessa.
    Lataa käyttöjärjestelmällesi sopiva versio GitHub-repositoriosta:

    Tarkista, että Windows-työkalu on digitaalisesti allekirjoitettu nimellä CSC - IT Center for Science. Latauksen jälkeen löydät Crypt4GH-sovelluksen latauskansiostasi.

    • Kun avaat sovelluksen ensimmäisen kerran, saatat kohdata virheilmoituksen. Tässä tapauksessa napsauta More info ja varmista, että julkaisija on CSC-IT Center for Science (tai suomeksi CSC-Tieteen tietotekniikan keskus Oy), ja napsauta sitten Run anyway.

    • Luo salausavaimesi:

      • Avaa Crypt4GH-sovellus ja napsauta Generate Keys (oikeassa yläkulmassa).
      • Työkalu avaa uuden ikkunan ja pyytää sinua syöttämään salasanan (Private Key Passphrase). Tämä salasana liitetään salaiseen avaimeesi. Käytä vahvaa salasanaa.
      • Kun napsautat OK, työkalu luo avainparin, joka koostuu salaisesta avaimesta (username_crypt4gh.key) ja julkisesta avaimesta (username_crypt4gh.pub).
      • Avaimet/tiedostonimet näytetään Activity Logissa seuraavan viestin yhteydessä:

        Key pair has been generated, your private key will be auto-loaded the next time you launch this tool:
        Private key: username_crypt4gh.key
        Public key: username_crypt4gh.pub
        All the fields must be filled before file encryption will be started
        

        Avaimet luodaan ja tallennetaan samaan kansioon, jossa sovellus sijaitsee.

      Note

      • Jos kadotat tai unohdat salaisen avaimesi tai salasanan, et pysty purkamaan tiedostojen salausta.
      • Älä jaa salaista avaintasi tai salasanaasi.
      • Sinun tarvitsee luoda avaimesi vain kerran ja käyttää niitä kaikkiin salaustarpeisiisi, mutta voit tietenkin halutessasi luoda erillisiä avaimia salausta varten.

Salausavainten luominen komentorivityökaluilla

Tässä esimerkissä luomme ensin avainparisi (salasanalla suojatun yksityisen avaimen ja julkisen avaimen, jonka voi jakaa yhteistyökumppaneille). Seuraavaksi salaamme tiedoston kahden eri yhteistyökumppanin julkisilla avaimilla (tutkimusryhmä A ja tutkimusryhmä B).

Python 3.6+ vaaditaan Crypt4GH-salausapuohjelman käyttämiseen. Jos tarvitset apua Pythonin asentamisessa, seuraa näitä ohjeita.

  1. Asenna Crypt4GH:n komentorivikäyttöliittymätyökalu

    Voit asentaa Crypt4GH:n suoraan pip-työkalulla:

    pip install crypt4gh     
    

    tai, jos haluat mieluummin uusimmat lähdekoodit GitHubista:

    pip install -r crypt4gh/requirements.txt
    pip install ./crypt4gh
    

    tai jopa:

    pip install git+https://github.com/EGA-archive/crypt4gh.git
    

    Tavallinen -h-valitsin näyttää eri vaihtoehdot, jotka työkalu hyväksyy:

    $ crypt4gh -h
    
    Utility for the cryptographic GA4GH standard, reading from stdin and outputting to stdout.
    
    Usage:
       {PROG} [-hv] [--log <file>] encrypt [--sk <path>] --recipient_pk <path> [--recipient_pk <path>]... [--range <start-end>]
       {PROG} [-hv] [--log <file>] decrypt [--sk <path>] [--sender_pk <path>] [--range <start-end>]
       {PROG} [-hv] [--log <file>] rearrange [--sk <path>] --range <start-end>
       {PROG} [-hv] [--log <file>] reencrypt [--sk <path>] --recipient_pk <path> [--recipient_pk <path>]... [--trim]
    
    Options:
       -h, --help             Prints this help and exit
       -v, --version          Prints the version and exits
       --log <file>           Path to the logger file (in YML format)
       --sk <keyfile>         Curve25519-based Private key.
                            When encrypting, if neither the private key nor C4GH_SECRET_KEY are specified, we generate a new key
       --recipient_pk <path>  Recipient's Curve25519-based Public key
       --sender_pk <path>     Peer's Curve25519-based Public key to verify provenance (akin to signature)
       --range <start-end>    Byte-range either as  <start-end> or just <start> (Start included, End excluded)
       -t, --trim             Keep only header packets that you can decrypt
    
    Environment variables:
       C4GH_LOG         If defined, it will be used as the default logger
       C4GH_SECRET_KEY  If defined, it will be used as the default secret key (ie --sk ${C4GH_SECRET_KEY})
    

    Saatat huomata, että crypt4gh käyttää yksityisestä avaimesta valitsinta --sk. Tämä voi tuntua oudolta, mutta ilmeisesti crypt4gh käyttää termiä secure key yksityisestä avaimesta, mistä tulee sk, ja vastaavasti pk viittaa julkiseen avaimeen eikä yksityiseen avaimeen.

  2. Luo julkinen-yksityinen avainparisi

    Käytät crypt4gh-keygen-komentoa yksityisen ja julkisen avaimesi luomiseen:

    $ crypt4gh-keygen --sk mykey.sec --pk mykey.pub
    Generating public/private Crypt4GH key pair.
    Enter passphrase for meykey.sec (empty for no passphrase): 
    Enter passphrase for mykey.sec (again): 
    Your private key has been saved in mykey.sec
    Your public key has been saved in mykey.pub
    

    missä --sk mykey.sec on yksityinen (salainen, sk) avaimesi ja --pk mykey.pub on julkinen avaimesi (pk). Työkalu pyytää sinua syöttämään salasanan (passphrase) yksityiselle avaimellesi. Turvallisuussyistä salasanaa ei näytetä kirjoittaessasi sitä, joten työkalu pyytää sinua syöttämään sen toisen kerran varmistaakseen, ettet tehnyt kirjoitusvirheitä (tai että teit samat virheet kahdesti). Käytä vahvaa salasanaa!

    Note

    Jos kadotat tai unohdat yksityisen avaimesi tai sen salasanan, et pysty purkamaan tiedostojen salausta. Älä jaa yksityistä avaintasi tai salasanaasi.

    Note

    Sinun tarvitsee luoda avaimesi vain kerran ja käyttää niitä kaikkiin salaustarpeisiisi, mutta voit tietenkin halutessasi luoda erillisiä avaimia salausta varten.

3. Esimerkki projektin avainten luomisesta

3.1 Avainten luominen

Alla olevassa esimerkissä tutkija Tiina Tutkija haluaa käyttää Allasta vastaanottaakseen ja tallentaakseen ihmisen sekvenssidataa,
jota hän käyttää uudessa tutkimusprojektissaan. Projektin nimi on AniMINE. Se kestää useita vuosia, ja siihen osallistuu useita tutkijoita ja datalähteitä.
Tiina Tutkijalla on jo CSC:llä asiakasprojekti, jossa on Allas-käyttöoikeus.

Nyt hän luo ja tallentaa projektille salausavaimet. Tiinalla on cryp4gh-gui
salausohjelma asennettuna kannettavaan tietokoneeseensa. Hän käyttää Generate Keys -toimintoa
luodakseen uuden salasanalla suojatun avainparin (tässä tapauksessa H8koGN3lzkke).
Luotujen avaintiedostojen nimet perustuvat luojan käyttäjätiliin
(salainen avain: ttutkija_crypt4gh.key, julkinen avain: ttutkija_crypt4gh.pub).
Koska avaimia käyttävät useat projektin jäsenet, Tiina nimeää tiedostot
uudelleen seuraavasti: animine_crypt4gh.key ja animine_crypt4gh.pub.

3.2 Avainten tallentaminen SD Connectiin

Seuraavaksi Tiina Tutkija kirjautuu SD Connectin selainkäyttöliittymään. Tiina käyttää Chromea parhaan käyttökokemuksen saamiseksi.

Kirjautumisen jälkeen hän tarkistaa, että vasemmassa yläkulmassa oleva Select project -pudotusvalikko viittaa siihen CSC-projektiin,
jota AniMINE-projekti käyttää. Sen jälkeen hän napsauttaa Create folder -painiketta (käyttöliittymässä ämpäreitä kutsutaan kansioiksi)
luodakseen uuden kansion nimeltä animine-keys. Sitten hän käyttää samaa painiketta luodakseen toisen
kansion nimeltä animine-pub. Huomaa, että ämpärien nimissä saa olla vain pieniä kirjaimia, numeroita ja merkki "-".

Nyt SD Connectissa on kaksi uutta tyhjää kansiota. Tiina avaa kansion amimine-keys ja käyttää Upload-
painiketta. Sitten hän käyttää Select files -toimintoa valitakseen molemmat avaimet ladattaviksi ja käynnistää latausprosessin napsauttamalla Upload-painiketta.

Kun lataus on valmis, Tiina siirtyy toiseen kansioon animine-pub.
Hän napsauttaa Upload-painiketta ja lataa tähän kansioon VAIN
julkisen avaimen (animine_crypt4gh.pub).

Lopuksi hän avaa yksinkertaisen tekstieditorin luodakseen lyhyen ohjetiedoston avaimista.
Tiedoston, jonka nimi on animine_key_instructions.txt, sisältö on seuraava:

---------------------------------------------------------------------------------------------------------
AniMINE  encryption keys created on 16.3. 2022 by project manager Tiina Tutkija.
Following key files are used to encrypt sensitive data used by AniMINE project.
Keys are used with crypt4gh encryption tool.
Public key:   animine_crypt4gh.pub
Secret key:   animine_crypt4gh.key
The password of the secret key is:  H8koGN3lzkke
Note that the secret key and password should never be given or shown to 
users that are not members of this project.

You can find a readable copy of the public key in SD Connect in location
    animine-pub/animine_crypt4gh.pub

You can freely download and send this public key to persons and organizations 
that provide data for AniMINE project. If you want to use data, that has 
been protected using this key pair, locally, please contact project manager 
Tiina Tutkija to get your own copy of the secret key and instructions for 
local decryption. Please use this document, that is readable only in the 
SD Desktop environment of this project, as the only written reference 
for the password. 

Delete the local copy of the secret key when it is no longer actively used. 
------------------------------------------------

Hän lataa tämän tekstitiedoston kansioon animine-keys ja poistaa sen sitten paikalliselta tietokoneeltaan.

Nyt kansio animine-keys sisältää tiedostot:

  • data/animine_crypt4gh.pub.c4gh
  • data/animine_crypt4gh.key.c4gh
  • data/animine_key_instructions.txt.c4gh

Ja kansio animine-pub sisältää tiedoston:

  • data/animine_crypt4gh.pub

4. Tallennusämpärin avaaminen datan tuontia varten datan tuottajalta

Kun sinulla on käyttöoikeus Allakseen, voit luoda sinne uuden dataämpärin ja jakaa tämän ämpärin datan tuottajan kanssa.
Tämä lähestymistapa edellyttää, että myös datan tuottajalla on projekti CSC:llä. Yleensä suomalaisilla akateemisilla datan tuottajilla,
kuten sekvensointikeskuksilla, on CSC-projekti. Voit kopioida projektisi julkisen avaimen jaettuun ämpäriin tai
lähettää julkisen avaimen datan tuottajalle jollakin muulla tavalla.

Suosittelemme, että pyydät datan tuottajaa salaamaan datasi CSC:n julkisella avaimella sekä
projektisi avaimella. Näin voit käyttää dataa sekä paikallisessa turvallisessa ympäristössäsi
että CSC:n sensitiivisen datan palveluissa.

4.1 Jaetun ämpärin luominen Roihulla

Jos tiedät datan tuottajan projektinumeron, voit helposti luoda jaetun Allas-
ämpärin käyttämällä rclone- ja a-commands-työkaluja Roihussa. Avaa ensin pääteyhteys osoitteeseen roihu-cpu.csc.fi (käytä SSH:ta, PuTTYä tai pääteyhteyttä Roihun selainkäyttöliittymästä).

Luvussa 2.2 meillä oli tutkija Tiina Tutkija, joka loi salausavaimet ja tallensi ne Allakseen.
Hänen tapauksessaan jaettu ämpäri voitaisiin luoda seuraavilla komennoilla.

Ensin Tiina Tutkija avaa yhteyden Roihuun. Selaimessa hän siirtyy osoitteeseen https://www.roihu.csc.fi ja kirjautuu CSC-käyttäjätilillään. Kun Roihun selainkäyttöliittymä on auki, hän avaa päätteen työkalulla:

Tools/Login node shell

Tämä työkalu tarjoaa pääteyhteyden Roihuun.

Päätteessä Tiina aktivoi yhteyden Allakseen:

module load allas
allas-conf --swift

Sitten hän luo uuden jaetun ämpärin käyttäen rclone- ja a-access-työkaluja:

rclone mkdir allas:animine-data-import-1
a-access --swift +rw project_2000111 animine-data-import-1

Ensimmäinen komento luo uuden ämpärin. Tässä tapauksessa Tiina käyttää ämpärin nimeä animine-data-import-1, koska ämpärien nimissä saa olla vain pieniä kirjaimia, numeroita ja merkki "-". Toinen komento antaa datan tuottajan projektille, tässä esimerkissä project_2000111, luku- ja kirjoitusoikeuden ämpäriin.

Sitten hän lataa julkisen avaimen Roihuun:

a-get --swift animine-pub/data/animine_crypt4gh.pub

Ja lataa avaimen jaettuun ämpäriin:

a-put --swift animine_crypt4gh.pub -b animine-data-import-1

Lopuksi Tiina lähettää jaetun ämpärin nimen datan tuottajalle
ja pyytää heitä salaamaan ladattavan datan sekä julkisella avaimella,
jonka he löytävät ämpäristä, että CSC:n julkisella avaimella.

4.2 Ämpärin jaon peruuttaminen datansiirron jälkeen

Suurten aineistojen (useita teratavuja) siirtäminen Allakseen voi kestää pitkään.
Muutaman päivän kuluttua datan tuottaja kertoo Tiinalle, että kaikki data on tuotu Allaksen jaettuun animine-data-import-1-ämpäriin.
Tiina voi nyt poistaa ulkoiset käyttöoikeudet ämpäristä komennolla:

a-access --swift -rw project_2000111 animine-data-import-1

5. Salatun datan käyttäminen

Edellä kuvatulla menettelyllä CSC:lle tallennettu data on vain tutkimusryhmän jäsenten käytettävissä. Data on salattu sekä CSC:n julkisella avaimella että tutkimusryhmän omalla julkisella avaimella. Jos dataa käytetään
SD Desktopin kautta, datan salauksen purku tehdään automaattisesti Data Gateway
-sovelluksessa, kun dataa käytetään työskentely-ympäristössä.

Jos dataa käytetään muissa ympäristöissä, käyttäjän täytyy purkaa salaus itse.

SD Connect -palvelussa jaettu ämpäri, tässä esimerkissä animine-data-import-1, vaatii joitakin valmisteluja ennen kuin ämpäriin ladattu data
voidaan ladata.

Ensin käyttäjän täytyy jakaa ämpäri myös omaan projektiinsa. Tämän jälkeen ladattuun dataan pääsee käsiksi
ei tavallisen All Folders -näkymän kautta, vaan SD Connectin Shared-näkymän kautta.

Yllä olevassa esimerkissä tutkija Tiina Tutkija jakoi Allas-palvelussa dataämpärin animine-data-import-1
vastaanottaakseen dataa sekvensointikeskukselta. Sekvensointikeskus latasi tiedoston run_12_R1.fastq.c4gh ämpäriin.
Tiina voi nyt käyttää SD Connectia ladatakseen tämän tiedoston paikalliselle tietokoneelleen.

  • Ensin Tiina tarkistaa projektinsa Project Identifier -merkkijonon, niin sanotun Share ID:n, ja kopioi sen leikepöydälle Copy Share ID -painikkeella.
  • Sen jälkeen hän painaa SD Connectin All Folders -näkymässä ämpärin (animine-data-import-1) Share-painiketta. Tämä avaa Bucket sharing -sivun. Tässä Tiina ottaa käyttöön Transfer-oikeudet ja lisää oman Project Identifier -tunnisteensa (sen voi kopioida SD Connectin pääsivulla projektinumeron vierestä) kenttään: Add Share IDs. Jako aktivoidaan napsauttamalla Share-painiketta.
  • Seuraavaksi Tiina siirtyy Shared to the project -näkymään, jossa nyt näkyy ämpäri animine-data-import-1.

Hän voi nyt avata ämpärin ja aloittaa datan lataamisen.

Lataamisen jälkeen tiedosto on kuitenkin edelleen salatussa muodossa. Purkaakseen tiedoston salauksen Tiina avaa cryp4gh-gui -salaustyökalun, jonka hän oli aiemmin asentanut tietokoneelleen salausavainten luomista varten.

Nyt hän käyttää tätä työkalua datan salauksen purkamiseen. crypt4gh-käyttöliittymässä hän napsauttaa ensin Load My Private Key ja valitsee sitten animine_crypt4gh.key-tiedoston, joka on hänen tutkimusprojektinsa käyttämä salainen avain. Sen jälkeen hän käyttää Select File -toimintoa valitakseen tiedoston run_12_R1.fastq.c4gh, jonka hän juuri latasi tietokoneelleen. Seuraavaksi hän napsauttaa Decrypt File -painiketta. crypt4gh-gui pyytää nyt salaisen avaimen salasanaa (H8koGN3lzkke tässä tapauksessa), minkä jälkeen tiedoston purettu versio, run_12_R1.fastq, luodaan salatun tiedoston viereen. Tiina voi nyt poistaa run_12_R1.fastq.c4gh-tiedoston paikalliselta tietokoneeltaan ja aloittaa työskentelyn run_12_R1.fastq-tiedoston kanssa.

Onko tämä sivu hyödyllinen?
Kiitos palautteestasi!
Kiitos! Arvostamme palautettasi.

Kerro meille miten voisimme parantaa tätä sivua ottamalla meihin yhteyttä .